@@ -47,6 +47,9 @@ from sphinx.util.compat import Directive
 from sphinx.util.docfields import Field, GroupedField
 from sphinx.util.docfields import DocFieldTransformer
 
+__version__ = open(path.join(path.dirname(__file__),
+                   "version.lisp-expr")).read().strip('"')
+
 ALL_TYPES = ["macro", "function", "genericFunction",
              "setf", "variable", "type"]
 upper_symbols = re.compile("([^a-z\s\"`]*[A-Z]{2,}[^a-z\s\"`:]*)($|\s)")
@@ -234,7 +237,9 @@ def specializer(sexp, state):
         if atom.startswith("KEYWORD:"):
             result.write("(EQL :%s)" % atom.split(":")[-1])
         else:
-            result.write(":cl:symbol:`~%s` " % atom)
+            result.write(":cl:symbol:`~%s`" % atom)
+        result.write(" ")
+
     node = nodes.list_item()
     result.seek(0)
     lines = string2lines(result.read())
